@@ -1,4 +1,4 @@
-import random
+from collections import Counter
 from unittest import mock
 
 import sentry_sdk
@@ -55,31 +55,35 @@ def test_monitor_unhealthy(sentry_init):
 
 
 def test_transaction_uses_downsampled_rate(
-    sentry_init, capture_client_reports, monkeypatch
+    sentry_init, capture_record_lost_event_calls, monkeypatch
 ):
     sentry_init(
         traces_sample_rate=1.0,
         transport=UnhealthyTestTransport(),
     )
 
-    reports = capture_client_reports()
+    record_lost_event_calls = capture_record_lost_event_calls()
 
     monitor = sentry_sdk.get_client().monitor
     monitor.interval = 0.1
 
-    # make sure rng doesn't sample
-    monkeypatch.setattr(random, "random", lambda: 0.9)
-
     assert monitor.is_healthy() is True
     monitor.run()
     assert monitor.is_healthy() is False
     assert monitor.downsample_factor == 1
 
-    with sentry_sdk.start_transaction(name="foobar") as transaction:
-        assert transaction.sampled is False
-        assert transaction.sample_rate == 0.5
+    # make sure we don't sample the transaction
+    with mock.patch("sentry_sdk.tracing_utils.Random.uniform", return_value=0.75):
+        with sentry_sdk.start_transaction(name="foobar") as transaction:
+            assert transaction.sampled is False
+            assert transaction.sample_rate == 0.5
 
-    assert reports == [("backpressure", "transaction")]
+    assert Counter(record_lost_event_calls) == Counter(
+        [
+            ("backpressure", "transaction", None, 1),
+            ("backpressure", "span", None, 1),
+        ]
+    )
 
 
 def test_monitor_no_thread_on_shutdown_no_errors(sentry_init):
